import 'package:flutter/material.dart';
import 'package:fluttertoast/fluttertoast.dart';
import 'package:weather_station/auth.dart';
import 'package:weather_station/pages/home.dart';
import 'package:weather_station/pages/login.dart';
import 'package:http/http.dart' as http;
import 'dart:convert';

Color background = const Color(0xff06B2A7);

class AddDevicePage extends StatefulWidget {
  AddDevicePage({super.key});

  @override
  _AddDevicePageState createState() => _AddDevicePageState();
}

class _AddDevicePageState extends State<AddDevicePage> {
  final TextEditingController serialText = TextEditingController();
  final TextEditingController nameText = TextEditingController();
  @override
  void initState() {
    super.initState();
  }

  @override
  Widget build(BuildContext context) {
    double menuSpace = 10;
    return Scaffold(
      appBar: AppBar(
        iconTheme: const IconThemeData(color: Colors.white),
        backgroundColor: background,
        title: const Text(
          "Add device",
          style: TextStyle(
            color: Color(0xffF6F6F6),
          ),
        ),
      ),
      body: Center(
        child: SizedBox(
          width: 250,
          child: Column(
            mainAxisAlignment: MainAxisAlignment.center,
            children: [
              Text(
                "Enter the Serial number of the station",
                textAlign: TextAlign.center,
              ),
              Padding(
                padding: const EdgeInsets.only(top: 20),
                child: Column(
                  children: [
                    TextField(
                      controller: serialText,
                      decoration:
                          const InputDecoration(hintText: 'Serial number'),
                    ),
                    Padding(
                      padding: const EdgeInsets.only(top: 20.0),
                      child: TextField(
                        controller: nameText,
                        decoration: const InputDecoration(
                            hintText: 'Name of the station'),
                      ),
                    ),
                  ],
                ),
              ),
              Padding(
                padding: const EdgeInsets.only(top: 50),
                child: SizedBox(
                  width: 150,
                  height: 50,
                  child: ElevatedButton(
                    onPressed: () async {
                      var statusCode = await addDevice(
                          serialText.text, nameText.text, context);
                      if (statusCode == 200) {
                        Fluttertoast.showToast(
                            msg: "Sucessfully added station");
                        Navigator.push(
                            context,
                            MaterialPageRoute(
                                builder: (context) => HomePage()));
                      } else {
                        Fluttertoast.showToast(msg: "Error adding the station");
                      }
                    },
                    child: Text(
                      'Add',
                      style: TextStyle(color: background),
                    ),
                  ),
                ),
              ),
            ],
          ),
        ),
      ),
    );
  }
}

Future<int> addDevice(String serialText, String nameText, context) async {
  print("Preparing to send request...");

  Map<String, String> body = {
    'idStation': serialText,
    'idUser': Auth.getUserId(),
    'nameOfStation': nameText,
  };
  String jsonBody = jsonEncode(body);
  print("Request JSON body: $jsonBody");

  Future<http.Response> postStation() {
    return http.post(
      Uri.parse('http://linux.kosickaakademia.sk:4207/AddStation'),
      headers: <String, String>{
        'Content-Type': 'application/json; charset=UTF-8',
      },
      body: jsonBody,
    );
  }

  var response = await postStation();
  print("Response Code: ${response.statusCode}");
  print("Response Body: ${response.body}");
  return response.statusCode;
}
