import 'package:flutter/material.dart';
import 'package:fluttertoast/fluttertoast.dart';
import 'package:firebase_auth/firebase_auth.dart';
import 'package:weather_station/auth.dart';
import 'package:weather_station/pages/login.dart';

String emailForPassword = "";

Color background = const Color(0xff06B2A7);
Color emailForPasswordColor = const Color(0xff121212);

class ForgotPasswordPage extends StatefulWidget {
  const ForgotPasswordPage({super.key});

  @override
  _ForgotPasswordPageState createState() => _ForgotPasswordPageState();
}

class _ForgotPasswordPageState extends State<ForgotPasswordPage> {
  final textController = TextEditingController();

  @override
  void dispose() {
    textController.dispose();
    super.dispose();
  }

  @override
  Widget build(BuildContext context) {
    return Scaffold(
      appBar: AppBar(
        iconTheme: IconThemeData(color: Colors.white),
        title: const Text(
          'Forgot password',
          style: TextStyle(color: Colors.white),
        ),
        backgroundColor: background,
      ),
      body: Container(
        color: background,
        child: Center(
          child: Padding(
            padding: const EdgeInsets.all(16.0),
            child: Column(
              mainAxisAlignment: MainAxisAlignment.center,
              children: [
                const Text(
                  'Please enter your email for your account',
                  style: TextStyle(fontSize: 18, color: Colors.white),
                  textAlign: TextAlign.center,
                ),
                const SizedBox(height: 20),
                TextField(
                  controller: textController,
                  cursorColor: emailForPasswordColor,
                  decoration: InputDecoration(
                    filled: true,
                    fillColor: const Color(0xffF6F6F6),
                    border: OutlineInputBorder(
                      borderRadius: BorderRadius.circular(10),
                      borderSide: BorderSide(color: emailForPasswordColor),
                    ),
                    enabledBorder: OutlineInputBorder(
                      borderSide: BorderSide(color: emailForPasswordColor),
                      borderRadius: BorderRadius.circular(10),
                    ),
                    focusedBorder: OutlineInputBorder(
                      borderSide:
                          BorderSide(color: emailForPasswordColor, width: 2.0),
                    ),
                    labelText: 'Email',
                    labelStyle: TextStyle(color: emailForPasswordColor),
                  ),
                ),
                const SizedBox(height: 20),
                GestureDetector(
                  onTap: () async {
                    setState(() {
                      emailForPassword = textController.text;
                      if (emailForPassword.length > 6 &&
                          emailForPassword.contains('@') &&
                          emailForPassword.contains('.')) {
                        emailForPasswordColor = const Color(0xff121212);
                      } else {
                        emailForPasswordColor = Colors.red;
                      }
                    });
                    try {
                      if (emailForPassword.length > 6 &&
                          emailForPassword.contains('@') &&
                          emailForPassword.contains('.')) {
                        await FirebaseAuth.instance
                            .sendPasswordResetEmail(email: emailForPassword);
                        Fluttertoast.showToast(
                          msg:
                              "Reset password email has been sent to $emailForPassword",
                        );
                        Navigator.push(
                            context,
                            MaterialPageRoute(
                                builder: (context) => LoginClass()));
                      }
                    } on Exception catch (e) {
                      print("error sending reset password $e");
                    }
                  },
                  child: Container(
                    width: 250,
                    height: 60,
                    decoration: BoxDecoration(
                      border: Border.all(color: Colors.black),
                      borderRadius: BorderRadius.circular(20),
                      color: const Color(0xffF6F6F6),
                    ),
                    child: const Center(
                      child: Text("Verify Email"),
                    ),
                  ),
                ),
              ],
            ),
          ),
        ),
      ),
    );
  }
}
