import 'package:fl_chart/fl_chart.dart';
import 'package:flutter/material.dart';
import 'package:intl/intl.dart';
import 'package:weather_station/pages/addInstructions.dart';
import 'package:weather_station/widgets/drawer.dart';
import 'package:weather_station/auth.dart';
import 'package:http/http.dart' as http;
import 'dart:convert';

int indexOfChart = 3;

final ssidText = TextEditingController();
final wifiPsswd = TextEditingController();
double displayTemp = 0.0;
double displayHumidity = 0.0;
double displayPressure = 0.0;
double displayQoA = 0.0;
Color background = const Color(0xff06B2A7);

class Station {
  final String id;
  final String name;

  Station(this.id, this.name);
}

class HomePage extends StatefulWidget {
  @override
  _HomePageState createState() => _HomePageState();
}

class _HomePageState extends State<HomePage> {
  List<Station> stations = [];
  int _currentIndex = 0;
  bool _isLoading = true;
  final PageController _pageController = PageController();
  List<FlSpot> chartData = [];
  List<FlSpot> spots = [];
  var dateTimes;
  @override
  void initState() {
    super.initState();
    getStations();
  }

  Future<void> getStations() async {
    //TODO auth niekedy neni persistent need to fix
    String userID = Auth.getUserId();
    Future<http.Response> fetchStations() {
      return http.get(
        Uri.parse(
            'http://linux.kosickaakademia.sk:4207/GetStations?idUser=$userID'),
        headers: <String, String>{
          'Content-Type': 'application/json; charset=UTF-8'
        },
      );
    }

    var response = await fetchStations();
    print("Response Code: ${response.statusCode}");
    print("Response Body: ${response.body}");

    if (response.statusCode == 200) {
      List<dynamic> stationData = json.decode(response.body);
      setState(() {
        stations = stationData
            .map((station) =>
                Station(station[0].toString(), station[2].toString()))
            .toList();
        _isLoading = false;
      });
      if (stations.isNotEmpty) {
        getMeasurements(stations[_currentIndex].id);
      }
    }
  }

  Future<void> getMeasurements(String stationID) async {
    setState(() {
      _isLoading = true;
    });

    String userID = Auth.getUserId();
    var response = await http.get(
      Uri.parse(
          'http://linux.kosickaakademia.sk:4207/GetMeasurement?idUser=$userID&idStation=$stationID'),
      headers: <String, String>{
        'Content-Type': 'application/json; charset=UTF-8',
      },
    );

    print(response.statusCode);
    if (response.statusCode == 200) {
      dateTimes = json.decode(response.body);
      //TODO FOUND ERROR, IF DATETIMES ARE EMPTY IT CRASHES
      //print("Measurements: $dateTimes");
      if (dateTimes.isNotEmpty) {
        print("Newest Measurement: ${dateTimes.last}");
        setState(() {
          //changing of the main display with current data
          displayTemp = double.parse(dateTimes.last[3].toStringAsFixed(2));
          displayHumidity = double.parse(dateTimes.last[4].toStringAsFixed(2));
          displayPressure = double.parse(dateTimes.last[5].toStringAsFixed(2));
          displayQoA = double.parse(dateTimes.last[6].toStringAsFixed(2));
          chartData = spots;
          _isLoading = false;
        });
      }
      if (dateTimes.isNotEmpty) {
        fillChartSpots(dateTimes);

        print("Display temp: $displayTemp");
        print("Display humidity: $displayHumidity");
        print("Display pressure: $displayPressure");
        print("Display QoA: $displayQoA");
      } else {
        print("No measurement data available");
        setState(() {
          _isLoading = false;
        });
      }
    } else {
      print("Failed to fetch measurements");
      setState(() {
        _isLoading = false;
      });
    }
  }

  void fillChartSpots(var dateTimes) {
    for (var data in dateTimes) {
      String timestamp = data[2];
      double value = data[indexOfChart];

      try {
        // Parsing of the timestamp
        DateTime dateTime =
            DateFormat('EEE, dd MMM yyyy HH:mm:ss \'GMT\'', 'en_US')
                .parse(timestamp);
        //formating this timestapm
        String formattedDate =
            DateFormat('yyyy-MM-dd – kk:mm').format(dateTime);

        //print(formattedDate);

        double xValue = dateTime.millisecondsSinceEpoch.toDouble();
        spots.add(FlSpot(xValue, value));
      } catch (e) {
        print("Error parsing date: $timestamp");
      }
    }
    print("Index was: $indexOfChart");
  }

  @override
  Widget build(BuildContext context) {
    return WillPopScope(
      onWillPop: () async => false,
      child: Scaffold(
        appBar: AppBar(
          iconTheme: const IconThemeData(color: Colors.white),
          backgroundColor: background,
          title: const Text("Home", style: TextStyle(color: Color(0xffF6F6F6))),
        ),
        drawer: drawer(),
        body: stations.isEmpty
            ? Center(
                child: Text(
                  "Add your first station",
                  style: TextStyle(fontSize: 20, color: Colors.grey),
                ),
              )
            : PageView.builder(
                controller: _pageController,
                itemCount: stations.length,
                onPageChanged: (index) {
                  setState(() {
                    _currentIndex = index;
                  });
                  getMeasurements(stations[index].id);
                },
                itemBuilder: (context, index) {
                  return SingleChildScrollView(
                    child: Padding(
                      padding: const EdgeInsets.all(16.0),
                      child: Column(
                        children: [
                          SizedBox(
                            height: 600,
                            child: Container(
                              width: double.infinity,
                              decoration: BoxDecoration(
                                color: const Color.fromARGB(7, 0, 0, 0),
                                borderRadius: BorderRadius.circular(50),
                              ),
                              child: Center(
                                child: _isLoading
                                    ? CircularProgressIndicator()
                                    : Column(
                                        mainAxisAlignment:
                                            MainAxisAlignment.center,
                                        children: [
                                          Text(
                                            "Station Name: ${stations[index].name}",
                                            style:
                                                const TextStyle(fontSize: 20),
                                          ),
                                          Padding(
                                            padding:
                                                const EdgeInsets.only(top: 20),
                                            child: Column(
                                              children: [
                                                Text(
                                                  "Temperature: $displayTemp°C",
                                                  style: const TextStyle(
                                                      fontSize: 20),
                                                ),
                                                Text(
                                                  "Humidity: $displayHumidity%",
                                                  style: const TextStyle(
                                                      fontSize: 20),
                                                ),
                                                Text(
                                                  "Pressure: $displayPressure hPa",
                                                  style: const TextStyle(
                                                      fontSize: 20),
                                                ),
                                                Text(
                                                  "Quality of Air: $displayQoA ppm",
                                                  style: const TextStyle(
                                                      fontSize: 20),
                                                ),
                                              ],
                                            ),
                                          ),
                                          SizedBox(height: 30),
                                          Padding(
                                            padding: const EdgeInsets.only(
                                                left: 15.0),
                                            child: Align(
                                              alignment: Alignment.centerLeft,
                                              child: GestureDetector(
                                                child: Text(
                                                  "Change",
                                                  style: TextStyle(
                                                      color: background,
                                                      fontWeight:
                                                          FontWeight.bold),
                                                ),
                                                onTap: () => {
                                                  setState(() {
                                                    chartData = [];
                                                  }),
                                                  setState(() {
                                                    switch (indexOfChart) {
                                                      case 2:
                                                        indexOfChart = 3;
                                                        break;
                                                      case 3:
                                                        print(
                                                            "setting to FOUR");
                                                        indexOfChart = 4;
                                                        break;
                                                      case 4:
                                                        indexOfChart = 5;
                                                        break;
                                                      case 5:
                                                        indexOfChart = 3;
                                                        break;
                                                    }
                                                  }),
                                                  print(
                                                      "Updated Index is: $indexOfChart"),
                                                  fillChartSpots(dateTimes)
                                                },
                                              ),
                                            ),
                                          ),
                                          Padding(
                                            padding:
                                                const EdgeInsets.only(top: 8.0),
                                            child: SizedBox(
                                                height: 200,
                                                width: 350,
                                                child: Padding(
                                                  padding:
                                                      const EdgeInsets.only(
                                                          right: 10.0),
                                                  child: LineChart(
                                                    LineChartData(
                                                      gridData: FlGridData(
                                                          show: false),
                                                      titlesData: FlTitlesData(
                                                        show: true,
                                                        leftTitles: AxisTitles(
                                                          axisNameWidget: Text(
                                                              'Temperature'),
                                                          sideTitles:
                                                              SideTitles(
                                                            reservedSize: 35,
                                                            showTitles: true,
                                                            getTitlesWidget:
                                                                (value, meta) {
                                                              return Padding(
                                                                padding:
                                                                    const EdgeInsets
                                                                        .only(
                                                                        left:
                                                                            10),
                                                                child: Text(value
                                                                    .toInt()
                                                                    .toString()),
                                                              );
                                                            },
                                                          ),
                                                        ),
                                                        bottomTitles:
                                                            AxisTitles(
                                                          axisNameWidget:
                                                              Text('Time'),
                                                          sideTitles:
                                                              SideTitles(
                                                            reservedSize: 25,
                                                            showTitles: true,
                                                            getTitlesWidget:
                                                                (value, meta) {
                                                              final DateTime
                                                                  dateTime =
                                                                  DateTime.fromMillisecondsSinceEpoch(
                                                                      value
                                                                          .toInt());
                                                              final String
                                                                  formattedTime =
                                                                  '${dateTime.hour}:${dateTime.minute.toString().padLeft(2, '0')}';
                                                              return Padding(
                                                                padding: EdgeInsets
                                                                    .only(
                                                                        top:
                                                                            10),
                                                                child: Transform
                                                                    .rotate(
                                                                  angle:
                                                                      -0.7854, // Rotation of a widget using radians
                                                                  child: Text(
                                                                    formattedTime,
                                                                    style: TextStyle(
                                                                        fontSize:
                                                                            7),
                                                                  ),
                                                                ),
                                                              );
                                                            },
                                                          ),
                                                        ),
                                                        topTitles: AxisTitles(
                                                          sideTitles:
                                                              SideTitles(
                                                                  showTitles:
                                                                      false),
                                                        ),
                                                        rightTitles: AxisTitles(
                                                          sideTitles:
                                                              SideTitles(
                                                                  showTitles:
                                                                      false),
                                                        ),
                                                      ),
                                                      borderData: FlBorderData(
                                                          show: true),
                                                      lineBarsData: [
                                                        LineChartBarData(
                                                          preventCurveOverShooting:
                                                              true,
                                                          spots: chartData,
                                                          isCurved: true,
                                                          curveSmoothness: 100,
                                                          color: Colors.orange,
                                                          barWidth: 3,
                                                          belowBarData:
                                                              BarAreaData(
                                                                  show: false),
                                                        ),
                                                      ],
                                                      extraLinesData:
                                                          ExtraLinesData(
                                                        horizontalLines: [
                                                          HorizontalLine(
                                                            y: 0,
                                                            color: Colors
                                                                .transparent,
                                                          ),
                                                          HorizontalLine(
                                                            y: chartData
                                                                    .isNotEmpty
                                                                ? ((chartData.map((e) => e.y).reduce((a, b) => a > b ? a : b) /
                                                                                5)
                                                                            .ceil() *
                                                                        5 +
                                                                    5)
                                                                : 55,
                                                            color: const Color
                                                                .fromARGB(
                                                                255, 0, 0, 0),
                                                          ),
                                                        ],
                                                        verticalLines: chartData
                                                            .map((spot) {
                                                          return VerticalLine(
                                                            x: spot.x,
                                                            color: Colors.grey,
                                                            strokeWidth: 1,
                                                            dashArray: [4, 2],
                                                          );
                                                        }).toList(),
                                                      ),
                                                      //finds the smallest values and rounds it down to the nearest multiplier of 5
                                                      minY: chartData.isNotEmpty
                                                          ? (chartData.map((e) => e.y).reduce((a, b) => a < b
                                                                              ? a
                                                                              : b) /
                                                                          5)
                                                                      .floor() *
                                                                  5 -
                                                              5
                                                          : 0,
                                                      //same as the one above but opposite so it rounds up
                                                      maxY: chartData.isNotEmpty
                                                          ? ((chartData.map((e) => e.y).reduce((a, b) => a > b
                                                                              ? a
                                                                              : b) /
                                                                          5)
                                                                      .ceil() *
                                                                  5 +
                                                              5)
                                                          : 25,
                                                      lineTouchData:
                                                          LineTouchData(
                                                        touchTooltipData:
                                                            LineTouchTooltipData(
                                                          getTooltipItems:
                                                              (touchedSpots) {
                                                            return touchedSpots
                                                                .map(
                                                                    (touchedSpot) {
                                                              final DateTime
                                                                  dateTime =
                                                                  DateTime.fromMillisecondsSinceEpoch(
                                                                      touchedSpot
                                                                          .x
                                                                          .toInt());
                                                              return LineTooltipItem(
                                                                '${dateTime.hour}:${dateTime.minute.toString().padLeft(2, '0')}, ${touchedSpot.y}',
                                                                const TextStyle(
                                                                    color: Colors
                                                                        .white),
                                                              );
                                                            }).toList();
                                                          },
                                                        ),
                                                      ),
                                                    ),
                                                  ),
                                                )),
                                          )
                                        ],
                                      ),
                              ),
                            ),
                          ),
                        ],
                      ),
                    ),
                  );
                },
              ),
        floatingActionButton: FloatingActionButton(
          backgroundColor: background,
          onPressed: () {
            Navigator.push(
              context,
              MaterialPageRoute(builder: (context) => const AddInstructions()),
            );
          },
          child: const Icon(Icons.add, color: Colors.white, size: 25),
        ),
      ),
    );
  }
}
