import 'package:flutter/material.dart';
import 'package:weather_station/widgets/drawer.dart';
import 'package:http/http.dart' as http;
import 'package:material_segmented_control/material_segmented_control.dart';

Color background = const Color(0xff06B2A7);

class SettingsClass extends StatefulWidget {
  @override
  _SettingsClassState createState() => _SettingsClassState();
}

class _SettingsClassState extends State<SettingsClass> {
  int _temperatureIndex = 0;
  int _pressureIndex = 0;
  int _qualityIndex = 0;

  @override
  void initState() {
    super.initState();
    //_fetchSettings();
  }

  Future<void> _fetchSettings() async {
    final response = await http.get(Uri.parse('urlka'));
    if (response.statusCode == 200) {
      setState(() {
        // settings = json.decode(response.body);
      });
    } else {
      print('Failed to load settings');
    }
  }

  @override
  Widget build(BuildContext context) {
    return Scaffold(
      drawer: drawer(),
      appBar: AppBar(
        iconTheme: const IconThemeData(color: Colors.white),
        backgroundColor: background,
        title: Text(
          'Settings',
          style: TextStyle(color: Colors.white),
        ),
      ),
      body: Center(
        child: Column(
          mainAxisAlignment: MainAxisAlignment.center,
          children: [
            Text("General"),
            Text("Temperature"),
            SizedBox(height: 5),
            MaterialSegmentedControl(
              children: {
                0: SizedBox(
                    width: 100,
                    child: Text(
                      '°C',
                      textAlign: TextAlign.center,
                    )),
                1: SizedBox(
                    width: 100,
                    child: Text(
                      '°F',
                      textAlign: TextAlign.center,
                    )),
              },
              selectionIndex: _temperatureIndex,
              borderColor: Colors.grey,
              selectedColor: background,
              unselectedColor: Colors.white,
              selectedTextStyle: TextStyle(color: Colors.white),
              unselectedTextStyle: TextStyle(color: background),
              borderWidth: 0.7,
              borderRadius: 32.0,
              onSegmentTapped: (index) {
                setState(() {
                  _temperatureIndex = index;
                });
              },
            ),
            Text("Atmospheric pressure"),
            SizedBox(height: 5),
            MaterialSegmentedControl(
              children: {
                0: SizedBox(
                    width: 100,
                    child: Text(
                      'Pascal',
                      textAlign: TextAlign.center,
                    )),
                1: SizedBox(
                    width: 100,
                    child: Text(
                      'hPa',
                      textAlign: TextAlign.center,
                    )),
                2: SizedBox(
                    width: 100,
                    child: Text(
                      'mBar',
                      textAlign: TextAlign.center,
                    )),
              },
              selectionIndex: _pressureIndex,
              borderColor: Colors.grey,
              selectedColor: background,
              unselectedColor: Colors.white,
              selectedTextStyle: TextStyle(color: Colors.white),
              unselectedTextStyle: TextStyle(color: background),
              borderWidth: 0.7,
              borderRadius: 32.0,
              onSegmentTapped: (index) {
                setState(() {
                  _pressureIndex = index;
                });
              },
            ),
            Text("Quality of air"),
            SizedBox(height: 5),
            MaterialSegmentedControl(
              children: {
                0: SizedBox(
                    width: 100,
                    child: Text(
                      '%',
                      textAlign: TextAlign.center,
                    )),
                1: SizedBox(
                    width: 100,
                    child: Text(
                      'ppm',
                      textAlign: TextAlign.center,
                    )),
              },
              selectionIndex: _qualityIndex,
              borderColor: Colors.grey,
              selectedColor: background,
              unselectedColor: Colors.white,
              selectedTextStyle: TextStyle(color: Colors.white),
              unselectedTextStyle: TextStyle(color: background),
              borderWidth: 0.7,
              borderRadius: 32.0,
              onSegmentTapped: (index) {
                setState(() {
                  _qualityIndex = index;
                });
              },
            ),
          ],
        ),
      ),
    );
  }
}
