import 'package:flutter/material.dart';
import 'package:fluttertoast/fluttertoast.dart';
import 'package:firebase_auth/firebase_auth.dart';
import 'package:weather_station/auth.dart';

String emailForVerification = "";

Color background = const Color(0xff06B2A7);
Color emailForVerificationColor = const Color(0xff121212);

class VerifyEmailPage extends StatefulWidget {
  const VerifyEmailPage({super.key});

  @override
  _VerifyEmailPageState createState() => _VerifyEmailPageState();
}

class _VerifyEmailPageState extends State<VerifyEmailPage> {
  final textController = TextEditingController();

  @override
  void dispose() {
    textController.dispose();
    super.dispose();
  }

  @override
  Widget build(BuildContext context) {
    return Scaffold(
      appBar: AppBar(
        iconTheme: IconThemeData(color: Colors.white),
        title: const Text(
          'Verify Email',
          style: TextStyle(color: Colors.white),
        ),
        backgroundColor: background,
      ),
      body: Container(
        color: background,
        child: Center(
          child: Padding(
            padding: const EdgeInsets.all(16.0),
            child: Column(
              mainAxisAlignment: MainAxisAlignment.center,
              children: [
                const Text(
                  'Please enter your email for verification',
                  style: TextStyle(fontSize: 18, color: Colors.white),
                  textAlign: TextAlign.center,
                ),
                const SizedBox(height: 20),
                TextField(
                  controller: textController,
                  cursorColor: emailForVerificationColor,
                  decoration: InputDecoration(
                    filled: true,
                    fillColor: const Color(0xffF6F6F6),
                    border: OutlineInputBorder(
                      borderRadius: BorderRadius.circular(10),
                      borderSide: BorderSide(color: emailForVerificationColor),
                    ),
                    enabledBorder: OutlineInputBorder(
                      borderSide: BorderSide(color: emailForVerificationColor),
                      borderRadius: BorderRadius.circular(10),
                    ),
                    focusedBorder: OutlineInputBorder(
                      borderSide: BorderSide(
                          color: emailForVerificationColor, width: 2.0),
                    ),
                    labelText: 'Email',
                    labelStyle: TextStyle(color: emailForVerificationColor),
                  ),
                ),
                const SizedBox(height: 20),
                GestureDetector(
                  onTap: () async {
                    setState(() {
                      emailForVerification = textController.text;
                      if (emailForVerification.length > 6 &&
                          emailForVerification.contains('@') &&
                          emailForVerification.contains('.')) {
                        emailForVerificationColor = const Color(0xff121212);
                      } else {
                        emailForVerificationColor = Colors.red;
                      }
                    });
                    try {
                      if (emailForVerification.length > 6 &&
                          emailForVerification.contains('@') &&
                          emailForVerification.contains('.')) {
                        User? user = FirebaseAuth.instance.currentUser;
                        if (user != null && !user.emailVerified) {
                          await user.sendEmailVerification();
                          Fluttertoast.showToast(
                            msg:
                                "Verification email has been sent to $emailForVerification",
                          );
                        } else {
                          Fluttertoast.showToast(
                            msg: "No user is logged in",
                          );
                        }
                      } else {
                        Fluttertoast.showToast(
                          msg: "Invalid email",
                        );
                      }
                    } on FirebaseAuthException catch (e) {
                      print("CHYBA: ${e.message}");

                      Fluttertoast.showToast(
                        msg: "Verification problem: ${e.message}",
                      );
                    }
                  },
                  child: Container(
                    width: 250,
                    height: 60,
                    decoration: BoxDecoration(
                      border: Border.all(color: Colors.black),
                      borderRadius: BorderRadius.circular(20),
                      color: const Color(0xffF6F6F6),
                    ),
                    child: const Center(
                      child: Text("Verify Email"),
                    ),
                  ),
                ),
              ],
            ),
          ),
        ),
      ),
    );
  }
}
