import { NavLink, useNavigate } from 'react-router-dom';
import { useEffect } from 'react';
import { getAuth, onAuthStateChanged } from 'firebase/auth';
import BtnDarkMode from '../btnDarkMode/BtnDarkMode';
import './style.css';

const Navbar = () => {
    const activeLink = 'nav-list__link nav-list__link--active';
    const normalLink = 'nav-list__link';
    const navigate = useNavigate();
    const auth = getAuth();

    useEffect(() => {
        const unsubscribe = onAuthStateChanged(auth, (user) => {
            const currentPath = window.location.pathname;

            if (!user && currentPath === '/account') {
                navigate('/login');
            } else if (
                user &&
                ['/login', '/register', '/reset'].includes(currentPath)
            ) {
                navigate('/account');
            }
        });

        return () => unsubscribe();
    }, [auth, navigate]);

    const isActiveAccountLink = () => {
        const currentPath = window.location.pathname;
        return ['/account', '/login', '/register', '/reset'].includes(currentPath);
    };

    return (
        <nav className="nav">
            <div className="container">
                <div className="nav-row">
                    <NavLink to="/" className="logo">
                        <strong>BAZPP</strong>
                        <span className="gradient-text"> team</span>
                    </NavLink>

                    <BtnDarkMode />

                    <ul className="nav-list">
                        <li className="nav-list__item">
                            <NavLink
                                to="/"
                                className={({ isActive }) =>
                                    isActive ? activeLink : normalLink
                                }
                            >
                                Home
                            </NavLink>
                        </li>

                        <li className="nav-list__item">
                            <NavLink
                                to="/projects"
                                className={({ isActive }) =>
                                    isActive ? activeLink : normalLink
                                }
                            >
                                Shop
                            </NavLink>
                        </li>
                        <li className="nav-list__item">
                            <NavLink
                                to="/account"
                                className={() =>
                                    isActiveAccountLink() ? activeLink : normalLink
                                }
                            >
                                Account
                            </NavLink>
                        </li>
                        <li className="nav-list__item">
                            <NavLink
                                to="/contacts"
                                className={({ isActive }) =>
                                    isActive ? activeLink : normalLink
                                }
                            >
                                Contacts
                            </NavLink>
                        </li>
                    </ul>
                </div>
            </div>
        </nav>
    );
};

export default Navbar;
