import React, { useEffect, useRef, useState } from 'react';
import { Chart, registerables } from 'chart.js';
import { getAuth, signOut } from 'firebase/auth';

Chart.register(...registerables);

const Account = () => {
  const chartRef1 = useRef(null);
  const chartRef2 = useRef(null);
  const chartRef3 = useRef(null);
  const [chart1, setChart1] = useState(null);
  const [chart2, setChart2] = useState(null);
  const [chart3, setChart3] = useState(null);
  const [selectedStation, setSelectedStation] = useState('station1'); 

  const Utils = {
    numbers: ({ count, min, max }) => Array(count).fill().map(() => Math.floor(Math.random() * (max - min + 1)) + min),
    CHART_COLORS: {
      lightBlue: 'hsl(195, 53.30%, 79.00%)',
    },
    transparentize: (color, opacity) => `${color.replace('rgb', 'rgba').replace(')', `, ${opacity})`)}`,
  };

  const generateHours = () => {
    return Array.from({ length: 24 }, (_, i) => `${i}:00`);
  };

  const data1_station1 = {
    labels: generateHours(),
    datasets: [
      {
        label: 'Humidity (%)',
        data: Utils.numbers({ count: 24, min: 0, max: 100 }),
        borderColor: Utils.CHART_COLORS.lightBlue,
        backgroundColor: Utils.transparentize(Utils.CHART_COLORS.lightBlue, 0.5),
        pointStyle: 'circle',
        pointRadius: 10,
        pointHoverRadius: 15,
      },
    ],
  };

  const data2_station1 = {
    labels: generateHours(),
    datasets: [
      {
        label: 'Temperature (°C)',
        data: Utils.numbers({ count: 24, min: -30, max: 40 }),
        borderColor: Utils.CHART_COLORS.lightBlue,
        backgroundColor: Utils.transparentize(Utils.CHART_COLORS.lightBlue, 0.5),
        pointStyle: 'circle',
        pointRadius: 10,
        pointHoverRadius: 15,
      },
    ],
  };

  const data3_station1 = {
    labels: generateHours(),
    datasets: [
      {
        label: 'Air Quality (%)',
        data: Utils.numbers({ count: 24, min: 0, max: 100 }),
        borderColor: Utils.CHART_COLORS.lightBlue,
        backgroundColor: Utils.transparentize(Utils.CHART_COLORS.lightBlue, 0.5),
        pointStyle: 'circle',
        pointRadius: 10,
        pointHoverRadius: 15,
      },
    ],
  };

  const data1_station2 = {
    labels: generateHours(),
    datasets: [
      {
        label: 'Humidity (%)',
        data: Utils.numbers({ count: 24, min: 0, max: 100 }),
        borderColor: Utils.CHART_COLORS.lightBlue,
        backgroundColor: Utils.transparentize(Utils.CHART_COLORS.lightBlue, 0.5),
        pointStyle: 'circle',
        pointRadius: 10,
        pointHoverRadius: 15,
      },
    ],
  };

  const data2_station2 = {
    labels: generateHours(),
    datasets: [
      {
        label: 'Temperature (°C)',
        data: Utils.numbers({ count: 24, min: -30, max: 40 }),
        borderColor: Utils.CHART_COLORS.lightBlue,
        backgroundColor: Utils.transparentize(Utils.CHART_COLORS.lightBlue, 0.5),
        pointStyle: 'circle',
        pointRadius: 10,
        pointHoverRadius: 15,
      },
    ],
  };

  const data3_station2 = {
    labels: generateHours(),
    datasets: [
      {
        label: 'Air Quality (%)',
        data: Utils.numbers({ count: 24, min: 0, max: 100 }),
        borderColor: Utils.CHART_COLORS.lightBlue,
        backgroundColor: Utils.transparentize(Utils.CHART_COLORS.lightBlue, 0.5),
        pointStyle: 'circle',
        pointRadius: 10,
        pointHoverRadius: 15,
      },
    ],
  };

  const config = {
    type: 'line',
    options: {
      responsive: true,
      maintainAspectRatio: false,
    },
  };

  useEffect(() => {
    const myChart1 = new Chart(chartRef1.current, { ...config, data: selectedStation === 'station1' ? data1_station1 : data1_station2 });
    const myChart2 = new Chart(chartRef2.current, { ...config, data: selectedStation === 'station1' ? data2_station1 : data2_station2 });
    const myChart3 = new Chart(chartRef3.current, { ...config, data: selectedStation === 'station1' ? data3_station1 : data3_station2 });
    setChart1(myChart1);
    setChart2(myChart2);
    setChart3(myChart3);

    return () => {
      myChart1.destroy();
      myChart2.destroy();
      myChart3.destroy();
    };
  }, [selectedStation]);

  const handleLogout = () => {
    const auth = getAuth();
    signOut(auth).then(() => {
      console.log('User signed out');
    }).catch((error) => {
      console.error('Error signing out:', error);
    });
  };

  return (
    <>
      <main className="section">
        <p className = "title-gradient-account">%Username%</p>
        <div className="container-account">
          {/* Station */}
          <div className="rectangle-account">
            <div className="content-account">
              <div 
                className={`rectangle-station ${selectedStation === 'station1' ? 'selected' : ''}`} 
                onClick={() => setSelectedStation('station1')}>
                <p className='title-gradient-station'>Station 1</p>
                <p><strong>Model:</strong> Base </p>
                <p><strong>Battery Status:</strong> 75%</p>
                <p><strong>Installation Date:</strong> December 12, 2024</p>
                <p><strong>Serial Number:</strong> WS-20241234-5678</p>
              </div>

              <div 
                className={`rectangle-station ${selectedStation === 'station2' ? 'selected' : ''}`} 
                onClick={() => setSelectedStation('station2')}>
                <p className='title-gradient-station'>Station 2</p>
                <p><strong>Model:</strong> Pro </p>
                <p><strong>Battery Status:</strong> 100%</p>
                <p><strong>Installation Date:</strong> December 12, 2024</p>
                <p><strong>Serial Number:</strong> WS-20241234-5678</p>
              </div>
            </div>
          </div>

          {/* Graphs */}
          <div className="rectangle-stats">
            <div className="content-stats">
              <div className="rectangle-graph">
                <canvas ref={chartRef1} width="400" height="200"></canvas>
              </div>
              <div className="rectangle-graph">
                <canvas ref={chartRef2} width="400" height="200"></canvas>
              </div>
              <div className="rectangle-graph">
                <canvas ref={chartRef3} width="400" height="200"></canvas>
              </div>
            </div>
          </div>
        </div>
        <button className="button-logout" onClick={handleLogout}>Log Out</button>
      </main>
    </>
  );
};

export default Account;
