import { useState } from 'react';
import { useNavigate } from 'react-router-dom';
import { getAuth, signInWithEmailAndPassword, signInWithPopup, GoogleAuthProvider } from 'firebase/auth';
import google from '../img/icons/google-icon.png';

// Firebase configuration
import { initializeApp } from "firebase/app";
import { getAnalytics } from "firebase/analytics";

const firebaseConfig = {
  apiKey: "AIzaSyD1cyq5NPs-gdn3c5BW5NCdshaAL-kI1YU",
  authDomain: "weatherstation1n.firebaseapp.com",
  projectId: "weatherstation1n",
  storageBucket: "weatherstation1n.firebasestorage.app",
  messagingSenderId: "344436116500",
  appId: "1:344436116500:web:1f5ec372e0adb4e5ffab01",
  measurementId: "G-VMHBDMQ1JK"
};

const app = initializeApp(firebaseConfig);
const analytics = getAnalytics(app);

const Login = () => {
    const [email, setEmail] = useState('');
    const [password, setPassword] = useState('');
    const [error, setError] = useState('');
    const navigate = useNavigate();
    const auth = getAuth();

    // Login with Email and Password
    const handleLogin = async () => {
        try {
            await signInWithEmailAndPassword(auth, email, password);
            navigate('/account'); 
        } catch (err) {
            setError("Password or email is wrong.");
        }
    };

    // Login with Google
    const handleGoogleLogin = async () => {
        const provider = new GoogleAuthProvider();
        try {
            await signInWithPopup(auth, provider);
            navigate('/account');
        } catch (err) {
            setError("Google login failed. Please try again.");
        }
    };

    const handleSignUpClick = () => {
        navigate('/register');
    };

    const handleForgotClick = () => {
        navigate('/reset');
    };

    return (
        <>
            <main className="section">
                <div className="container">
                    <div className="rectangle-login">
                        <div className="content-login">
                            <p className = "title-2">Login</p>
                            {error && <p style={{ color: 'red' }}>{error}</p>}
                            <input
                                type="email"
                                className="input1"
                                placeholder="Enter your email"
                                value={email}
                                onChange={(e) => setEmail(e.target.value)}
                            />
                            <input
                                type="password"
                                className="input1"
                                placeholder="Enter your password"
                                value={password}
                                onChange={(e) => setPassword(e.target.value)}
                            />
                            <button className="button-login" onClick={handleLogin}>
                                Login
                            </button>
                            <button className="button-login-google" onClick={handleGoogleLogin}>
                                <img src={google} alt="Google icon" className="button-icon" />
                                Login with Google
                            </button>
                            <button className="button-signup-navigate" onClick={handleSignUpClick}>
                                Sign Up
                            </button>
                            <button className="button-forgot-navigate" onClick={handleForgotClick}>
                                Forgot Password?
                            </button>
                        </div>
                    </div>
                </div>
            </main>
        </>
    );
};

export default Login;
