import { useState } from 'react';
import { useNavigate } from 'react-router-dom';
import { getAuth, createUserWithEmailAndPassword, signInWithPopup, GoogleAuthProvider } from 'firebase/auth';
import google from '../img/icons/google-icon.png';

const Register = () => {
    const [email, setEmail] = useState('');
    const [username, setUsername] = useState(''); 
    const [password, setPassword] = useState('');
    const [confirmPassword, setConfirmPassword] = useState('');
    const [error, setError] = useState('');
    const navigate = useNavigate();
    const auth = getAuth();

    // Handle regular email and password registration
    const handleRegister = async () => {
        if (password !== confirmPassword) {
            setError("Passwords don't match.");
            return;
        }

        try {
            const userCredential = await createUserWithEmailAndPassword(auth, email, password);
            console.log('User registered:', userCredential.user);
            navigate('/login'); 
        } catch (err) {
            setError(err.message);
        }
    };

    // Handle registration via Google
    const handleGoogleLogin = async () => {
        const provider = new GoogleAuthProvider();
        try {
            // Using signInWithPopup to register or log in with Google
            const result = await signInWithPopup(auth, provider);
            const user = result.user;
            console.log('Google user registered:', user);
            navigate('/login');
        } catch (err) {
            setError("Google login failed. Please try again.");
        }
    };

    const handleLoginClick = () => {
        navigate('/login');
    };

    const handleForgotClick = () => {
        navigate('/reset');
    };

    return (
        <>
            <main className="section">
                <div className="container">
                    <div className="rectangle-login">
                        <div className="content-login">
                            <p className="title-2">Register</p>
                            {error && <p style={{ color: 'red' }}>{error}</p>}
                            <input
                                type="email"
                                className="input1"
                                placeholder="Enter your email"
                                value={email}
                                onChange={(e) => setEmail(e.target.value)}
                            />
                            <input
                                type="text"
                                className="input1"
                                placeholder="Enter your username"
                                value={username}
                                onChange={(e) => setUsername(e.target.value)}
                            />
                            <input
                                type="password"
                                className="input1"
                                placeholder="Enter your password"
                                value={password}
                                onChange={(e) => setPassword(e.target.value)}
                            />
                            <input
                                type="password"
                                className="input1"
                                placeholder="Repeat your password"
                                value={confirmPassword}
                                onChange={(e) => setConfirmPassword(e.target.value)}
                            />
                            <div className="checkbox-container">
                                <input type="checkbox" id="tos-checkbox" className="checkbox" />
                                <label htmlFor="tos-checkbox" className="checkbox-label">
                                    I agree with the ToS
                                </label>
                            </div>
                            <button className="button-login" onClick={handleRegister}>
                                Register
                            </button>
                            <button className="button-login-google" onClick={handleGoogleLogin}>
                                <img src={google} alt="Google icon" className="button-icon" />
                                Register with Google
                            </button>
                            <button className="button-signup-navigate" onClick={handleLoginClick}>
                                Login
                            </button>
                            <button className="button-forgot-navigate" onClick={handleForgotClick}>
                                Forgot Password?
                            </button>
                        </div>
                    </div>
                </div>
            </main>
        </>
    );
};

export default Register;
