import { useState } from 'react';
import { useNavigate } from 'react-router-dom';
import { getAuth, sendPasswordResetEmail } from 'firebase/auth';

const Reset = () => {
    const [email, setEmail] = useState('');
    const [message, setMessage] = useState('');
    const [error, setError] = useState('');
    const navigate = useNavigate();
    const auth = getAuth();

    const handleResetPassword = async () => {
        setMessage('');
        setError('');
        try {
            await sendPasswordResetEmail(auth, email);
            setMessage('Password reset email sent. Check your inbox!');
        } catch (err) {
            setError('Failed to send reset email. Please check your email address.');
        }
    };

    const handleLoginClick = () => {
        navigate('/login');
    };

    return (
        <>
            <main className="section">
                <div className="container">
                    <div className="rectangle-login">
                        <div className="content-login">
                            <p className="title-2">Reset Password</p>
                            {message && <p style={{ color: 'green' }}>{message}</p>}
                            {error && <p style={{ color: 'red' }}>{error}</p>}
                            <input
                                type="email"
                                className="input1"
                                placeholder="Enter your email"
                                value={email}
                                onChange={(e) => setEmail(e.target.value)}
                            />
                            <button className="button-login" onClick={handleResetPassword}>
                                Send email
                            </button>
                            <button className="button-signup-navigate" onClick={handleLoginClick}>
                                Login
                            </button>
                        </div>
                    </div>
                </div>
            </main>
        </>
    );
};

export default Reset;
